@@ -43,6 +43,7 @@ except ImportError:
     import thread  # py2
 
 import threading
+from flup.server import get_errno
 thread_available = True
 
 if sys.hexversion >= 0x03000000:
@@ -655,7 +656,7 @@ class Connection(object):
             except (EOFError, KeyboardInterrupt):
                 break
             except (select.error, socket.error) as e:
-                if e.errno == errno.EBADF: # Socket was closed by Request.
+                if get_errno(e) == errno.EBADF: # Socket was closed by Request.
                     break
                 raise
 
