@@ -43,6 +43,7 @@ else:
         fcntl.fcntl(sock.fileno(), fcntl.F_SETFD, fcntl.FD_CLOEXEC)
 
 from flup.server.threadpool import ThreadPool
+from flup.server import get_errno
 
 __all__ = ['ThreadedServer']
 
@@ -75,7 +76,7 @@ class ThreadedServer(object):
             try:
                 r, w, e = select.select([sock], [], [], timeout)
             except select.error as e:
-                if e.errno == errno.EINTR:
+                if get_errno(e) == errno.EINTR:
                     continue
                 raise
 
